/*
 * Copyright (c) 2007, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wso2.registry;

import org.wso2.registry.exceptions.RegistryException;
import org.wso2.registry.config.RegistryContext;

import java.util.Map;
import java.util.Date;

public class ChrootRegistry implements Registry {
    // The URL prefix to use for all accesses - must end with a slash
    protected String basePrefix = "";

    public ChrootRegistry(String basePrefix) {
        this.basePrefix = basePrefix;
    }

    public ChrootRegistry() {
    }

    /**
     * Get an absolute path for the given path argument, taking into
     * account both initial double-slashes (indicating an absolute path)
     * and any basePrefix that has been established.
     *
     * This is the converse of getRelativePath().
     *
     * @param path a relative path
     * @return an absolute path into the "real" registry.
     */
    public String getRealPath(String path) {
        if (path == null || path.length() == 0) return null;

        if (path.startsWith("//")) {
            // This is an absolute path, so just strip the doubled slash
            return path.substring(1);
        }

        // Relative path, so prepend basePrefix appropriately
        if (path.startsWith("/")) {
            return basePrefix + path.substring(1);
        }

        return basePrefix + "/" + path;
    }

    /**
     * Take an absolute path in the "real" registry and convert it to a relative
     * path suitable for this particular RemoteRegistry (which may be rooted at a
     * particular place).
     *
     * This is the converse of getRealPath().
     *
     * @param absolutePath a full path from the root of the registry, starting with "/"
     * @return a relative path which generates the correct absolute path
     */
    public String getRelativePath(String absolutePath) {
        // No worries if there's no base prefix
        if (basePrefix == null || basePrefix.length() == 0) return absolutePath;

        if (absolutePath.startsWith(basePrefix)) {
            return absolutePath.substring(basePrefix.length() - 1);
        }

        // Somewhere else, so make sure there are dual slashes at the beginning
        return "/" + absolutePath;
    }

    public String importResource(String suggestedPath, String sourceURL, Resource metadata)
            throws RegistryException {
        return null;
    }

    public String rename(String currentPath, String newName) throws RegistryException {
        return null;
    }

    public String move(String currentPath, String newPath) throws RegistryException {
        return null;
    }

    public String copy(String sourcePath, String targetPath) throws RegistryException {
        return null;
    }

    public void createVersion(String path) throws RegistryException {
    }

    public String[] getVersions(String path) throws RegistryException {
        return new String[0];
    }

    public void restoreVersion(String versionPath) throws RegistryException {
    }////////////////////////////////////////////////////////
    // Associations
    ////////////////////////////////////////////////////////
    public void addAssociation(String sourcePath, String targetPath, String associationType)
            throws RegistryException {
    }

    public void removeAssociation(String sourcePath, String targetPath, String associationType)
            throws RegistryException {
    }

    public Association[] getAllAssociations(String resourcePath) throws RegistryException {
        return new Association[0];
    }

    public Association[] getAssociations(String resourcePath, String associationType)
            throws RegistryException {
        return new Association[0];
    }

    public void applyTag(String resourcePath, String tag) throws RegistryException {
    }

    public TaggedResourcePath[] getResourcePathsWithTag(String tag) throws RegistryException {
        return new TaggedResourcePath[0];
    }

    public Tag[] getTags(String resourcePath) throws RegistryException {
        return new Tag[0];
    }

    public void removeTag(String path, String tag) throws RegistryException {
    }

    public String addComment(String resourcePath, Comment comment) throws RegistryException {
        return null;
    }

    public void editComment(String commentPath, String text) throws RegistryException {
    }

    public Comment[] getComments(String resourcePath) throws RegistryException {
        return new Comment[0];
    }

    public void rateResource(String resourcePath, int rating) throws RegistryException {
    }

    public float getAverageRating(String resourcePath) throws RegistryException {
        return 0;
    }

    public int getRating(String path, String userName) throws RegistryException {
        return 0;
    }

    public Collection executeQuery(String path, Map parameters) throws RegistryException {
        return null;
    }

    public LogEntry[] getLogs(String resourcePath,
                              int action,
                              String userName,
                              Date from,
                              Date to,
                              boolean recentFirst) throws RegistryException {
        return new LogEntry[0];
    }

    public LogEntryCollection getLogCollection(String resourcePath,
                                               int action,
                                               String userName,
                                               Date from,
                                               Date to,
                                               boolean recentFirst) throws RegistryException {
        return null;
    }

    public String[] getAvailableAspects() {
        return new String[0];
    }

    public void associateAspect(String resourcePath, String aspect) throws RegistryException {
    }

    public void invokeAspect(String resourcePath, String aspectName, String action)
           throws RegistryException {
    }

    public String[] getAspectActions(String resourcePath, String aspectName)
           throws RegistryException {
        return new String[0];
    }

    public void beginTransaction() throws RegistryException {
    }

    public void commitTransaction() throws RegistryException {
    }

    public void rollbackTransaction() throws RegistryException {
    }

    public RegistryContext getRegistryContext() {
        return null;
    }

    public Collection searchContent(String keywords) throws RegistryException {
        return null;
    }

    public Resource newResource() throws RegistryException {
        return null;
    }

    public Collection newCollection() throws RegistryException {
        return null;
    }

    public Resource get(String path) throws RegistryException {
        return null;
    }

    public Collection get(String path, int start, int pageSize) throws RegistryException {
        return null;
    }

    public boolean resourceExists(String path) throws RegistryException {
        return false;
    }

    public String put(String suggestedPath, Resource resource) throws RegistryException {
        return null;
    }

    public void delete(String path) throws RegistryException {
    }
}
