/*
 * Copyright (c) 2008, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.app;

import org.wso2.registry.*;
import org.wso2.registry.jdbc.JDBCRegistryTest;

import java.util.ArrayList;
import java.util.List;

//This test case run all the test cases that there in JDBCRegistry using RemoteRegistry

public class ChrootedRemoteTest extends JDBCRegistryTest {
    RegistryServer server = new RegistryServer();
    String clientPort = "8081";

    public void setUp() {
        try {
            String portProp = System.getProperty("clientPort");
            if (portProp != null) {
                clientPort = portProp;
            }

            if (registry == null) {
                server.start();
                registry = new RemoteRegistry("http://localhost:" + clientPort + "/wso2registry",
                                              "/testPrefix",
                                              "admin",
                                              "admin");
            }
        } catch (Exception e) {
            fail("Failed to initialize the registry.");
        }
    }

    public void testResourceWithSpaces() throws Exception {
        Resource r1 = registry.newResource();
        String realPath = registry.put("/ws/my resource", r1);
        r1 = registry.get(realPath);
        assertNotNull(r1);
    }

    public void testAddComment() throws Exception {
        Resource r1 = registry.newResource();
        byte[] r1content = "R1 content".getBytes();
        r1.setContent(r1content);
        registry.put("/d1/r3", r1);

        String comment1 = "this is qa comment 4";
        String comment2 = "this is qa comment 5";
        Comment c1 = new Comment();
        c1.setResourcePath("/d1/r3");
        c1.setText("This is default comment");
        c1.setUser("admin1");

        registry.addComment("/d1/r3", c1);
        registry.addComment("/d1/r3", new Comment(comment1));
        registry.addComment("/d1/r3", new Comment(comment2));

        Comment[] comments = registry.getComments("/d1/r3");

        boolean commentFound = false;

        for (Comment comment : comments) {
            if (comment.getText().equals(comment1)) {
                commentFound = true;
                assertEquals(comment1, comment.getText());
                assertEquals("admin", comment.getUser());
                assertEquals("/d1/r3", comment.getResourcePath());
                //break;
            }

            if (comment.getText().equals(comment2)) {
                commentFound = true;
                assertEquals(comment2, comment.getText());
                assertEquals("admin", comment.getUser());
                assertEquals("/d1/r3", comment.getResourcePath());
                //break;
            }

            if (comment.getText().equals("This is default comment")) {
                commentFound = true;
                assertEquals("This is default comment", comment.getText());
                assertEquals("admin", comment.getUser());
                //break;
            }
        }


        assertTrue("comment '" + comment1 +
                   " is not associated with the artifact /d1/r3", commentFound);

        Resource commentsResource = registry.get("/d1/r3;comments");
        assertTrue("Comment collection resource should be a directory.",
                   commentsResource instanceof Collection);
        comments = (Comment[])commentsResource.getContent();

        List commentTexts = new ArrayList();
        for (Comment comment : comments) {
            Resource commentResource = registry.get(comment.getPath());
            commentTexts.add(commentResource.getContent());
        }

        assertTrue(comment1 + " is not associated for resource /d1/r3.",
                   commentTexts.contains(comment1));
        assertTrue(comment2 + " is not associated for resource /d1/r3.",
                   commentTexts.contains(comment2));
    }


}